@@ -6,8 +6,9 @@ def from_settings(request):
         'input_methods': settings.COVE_CONFIG.get('input_methods', []),
         'app_verbose_name': settings.COVE_CONFIG.get('app_verbose_name', []),
 
-        'piwik': settings.PIWIK,
-        'google_analytics_id': settings.GOOGLE_ANALYTICS_ID,
+        'piwik': getattr(settings, 'PIWIK', {'dimension_map': {}}),
+        'google_analytics_id': getattr(settings, 'GOOGLE_ANALYTICS_ID', ''),
+        'sentry_dsn': getattr(settings, 'SENTRY_DSN', ''),
 
         'delete_files_after_days': getattr(settings, 'DELETE_FILES_AFTER_DAYS', 7),
     }
